@@ -1,4 +1,9 @@
 from .event import Event
 from .create import CreateEvent, CreateBranchEvent, CreateTagEvent
-from .issue_comment import IssueCommentEvent, IssueCommentCreatedEvent, IssueCommentEditedEvent, IssueCommentDeletedEvent
+from .issue_comment import (
+    IssueCommentEvent,
+    IssueCommentCreatedEvent,
+    IssueCommentEditedEvent,
+    IssueCommentDeletedEvent,
+)
 from .release import ReleaseCreatedEvent, ReleaseReleasedEvent
